@@ -367,10 +367,9 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
         while True:
             if task_data and 'status' in task_data:
 
-                # todo - yuck! please update backend APIs!
                 if server_type == 'feeds' and 'taskId' in task_data:
                     task_id = task_data['taskId']
-                elif server_type == 'dictionary' and 'id' in task_data:
+                elif 'id' in task_data:
                     task_id = task_data['id']
                 else:
                     raise GracieAPIResponseError('Task id not found in results')
@@ -382,16 +381,10 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
                     break
             time.sleep(sleep_time)
 
-        # todo - yuck! please update backend APIs!
         if remove_results:
-            if server_type == 'dictionary':
-                self.call_api('tasksController', 'delete', id=task_id)
-                if task_data['error']:
-                    raise GracieError(task_data['error'])
-            else:
-                self.call_api('tasksController', 'remove', id=task_id)
-                if task_data['errorMessage']:
-                    raise GracieError(task_data['errorMessage'])
+            self.call_api('tasksController', 'delete', id=task_id)
+            if task_data['error']:
+                raise GracieError(task_data['error'])
 
         if self._full_results:
             return task_data
