@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class approversController(GracieBaseAPI):
-    """Approver is someone who can approve edited by editors data in the database."""
+    """Approvers Controller"""
 
     _controller_name = "approversController"
 
