@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class briefController(GracieBaseAPI):
-    """Brief."""
+    """Brief Controller"""
 
     _controller_name = "briefController"
 
