@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class countryController(GracieBaseAPI):
-    """Countries."""
+    """Country Controller"""
 
     _controller_name = "countryController"
 
