@@ -124,6 +124,7 @@ class databasesController(GracieBaseAPI):
         Args:
             dictionaryId: (string): dictionaryId
             recalculateDocumentsVectors: (boolean): recalculateDocumentsVectors
+            testSubclasses: (boolean): testSubclasses
 
         Consumes:
             application/json
@@ -132,7 +133,7 @@ class databasesController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'dictionaryId': {'name': 'dictionaryId', 'required': False, 'in': 'query'}, 'recalculateDocumentsVectors': {'name': 'recalculateDocumentsVectors', 'required': False, 'in': 'query'}}
+        all_api_parameters = {'dictionaryId': {'name': 'dictionaryId', 'required': False, 'in': 'query'}, 'recalculateDocumentsVectors': {'name': 'recalculateDocumentsVectors', 'required': False, 'in': 'query'}, 'testSubclasses': {'name': 'testSubclasses', 'required': False, 'in': 'query'}}
         parameters_names_map = {}
         api = '/databases/updateDictionaries'
         actions = ['post']
@@ -144,7 +145,7 @@ class databasesController(GracieBaseAPI):
         """
 
         Args:
-            Corpus file name (without folder path). File has to be in [data_sources/knowledge/corpus] directory: (string): Corpus file name (without folder path). File has to be in [data_sources/knowledge/corpus] directory
+            customCorpusFileName: (string): customCorpusFileName
             languageId: (string): languageId
             updateDoc2vec: (boolean): updateDoc2vec
             updateIdfModel: (boolean): updateIdfModel
@@ -156,7 +157,7 @@ class databasesController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'Corpus file name (without folder path). File has to be in [data_sources/knowledge/corpus] directory': {'name': 'Corpus file name (without folder path). File has to be in [data_sources/knowledge/corpus] directory', 'required': False, 'in': 'query'}, 'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}, 'updateDoc2vec': {'name': 'updateDoc2vec', 'required': False, 'in': 'query'}, 'updateIdfModel': {'name': 'updateIdfModel', 'required': False, 'in': 'query'}}
+        all_api_parameters = {'customCorpusFileName': {'name': 'customCorpusFileName', 'required': False, 'in': 'query'}, 'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}, 'updateDoc2vec': {'name': 'updateDoc2vec', 'required': False, 'in': 'query'}, 'updateIdfModel': {'name': 'updateIdfModel', 'required': False, 'in': 'query'}}
         parameters_names_map = {}
         api = '/databases/updateLanguage'
         actions = ['post']
