@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class editorsController(GracieBaseAPI):
-    """Editor - is someone who can edit data in the database. """
+    """Editors Controller"""
 
     _controller_name = "editorsController"
 
