@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class featureClassController(GracieBaseAPI):
-    """Features classes."""
+    """Feature Class Controller"""
 
     _controller_name = "featureClassController"
 
