@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class geoCodesController(GracieBaseAPI):
-    """Phone and postal codes."""
+    """Geo Codes Controller"""
 
     _controller_name = "geoCodesController"
 
