@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class nameController(GracieBaseAPI):
-    """Name. """
+    """Name Controller"""
 
     _controller_name = "nameController"
 
