@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class performanceController(GracieBaseAPI):
-    """Text processing performance measurement"""
+    """Performance Controller"""
 
     _controller_name = "performanceController"
 
