@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class stopWordController(GracieBaseAPI):
-    """Stop words."""
+    """Stop Word Controller"""
 
     _controller_name = "stopWordController"
 
