@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class summarizerController(GracieBaseAPI):
-    """Summarize text down to N sentences."""
+    """Summarizer Controller"""
 
     _controller_name = "summarizerController"
 
