@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class tasksController(GracieBaseAPI):
-    """Task"""
+    """Tasks Controller"""
 
     _controller_name = "tasksController"
 
