@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class testGroupsController(GracieBaseAPI):
-    """Test groups"""
+    """Test Groups Controller"""
 
     _controller_name = "testGroupsController"
 
