@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class userTypesController(GracieBaseAPI):
-    """User types."""
+    """User Types Controller"""
 
     _controller_name = "userTypesController"
 
