@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class webLinksController(GracieBaseAPI):
-    """Web links. """
+    """Web Links Controller"""
 
     _controller_name = "webLinksController"
 
